-------------------------------------------------------------------------------
-- Name: class TerminalCommunicator
-- Author: Jonathan Primeau
--
-- Description:
--     This is the layer between XMLSocket and high level calls.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
-------------------------------------------------------------------------------

property ancestor              -- Parent
property pFlashConnector
property pCallback


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Terminal").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Connect (me)
  ancestor.SetIP("127.0.0.1")
  ancestor.SetPort(4635)
  ancestor.SetConnectionCallback(void, void)
  ancestor.SetMessageCallback(#_MessageHandler, me)
  ancestor.Connect()
end

on OnConnect (me, theStatus)
  ancestor.OnConnect(theStatus)
end

on OnData (me, theData)
  ancestor.OnData(theData)
end

on OnClose (me)
  ancestor.OnClose()
end

on Disconnect (me)
  ancestor.Disconnect()
end

on IsConnected (me)
  return(ancestor.IsConnected())
end

on Events (me, theHandler, theObject)
  me.pCallback.handler = theHandler
  me.pCallback.object = theObject
  
  lXML = "<Events Type=" &QUOTE& "Main" &QUOTE& "/>"
  
  ancestor.SendCommand(lXML)
end

on Wager (me, theData, theHandler, theObject)
  me.pCallback.handler = theHandler
  me.pCallback.object = theObject
  
  ancestor.SendCommand(theData)
end

on Navigate (me, theRace, theEvent, theChannel, theHandler, theObject)
  me.pCallback.handler = theHandler
  me.pCallback.object = theObject
  
  lXML = "<Navigate"
  
  if (theRace <> void) then
    lXML = lXML && "Race=" &QUOTE& string(theRace) &QUOTE
  end if
  if (theEvent <> void) then
    lXML = lXML && "Event=" &QUOTE& string(theEvent) &QUOTE
  end if
  if (theChannel <> void) then
    lXML = lXML && "Channel=" &QUOTE& string(theChannel) &QUOTE
  end if
  lXML = lXML & "/>"
  
  ancestor.SendCommand(lXML)
end

on EndPatron (me, theHandler, theObject)
  me.pCallback.handler = theHandler
  me.pCallback.object = theObject
  
  lXML = "<EndPatron/>"
  
  ancestor.SendCommand(lXML)
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pFlashConnector = sprite("Terminal")
  me.pCallback = [#handler: void, #object: void]
end

on _MessageHandler (me, theContent)
  
  -- We received a message from the terminal, parse it.
  if (theContent starts "<Events") then
    
    call(me.pCallback.handler, me.pCallback.object, theContent)
    
  else if (theContent starts "<BeginPatron") then
    
    QI(#patron).BeginPatron(theContent)
    
  else if (theContent starts "<EndPatron") then
    
    QI(#patron).EndPatron(theContent)
    
  else if (theContent starts "<MagCard") then
    
    QI(#patron).SwipeCard(theContent)
    
  else if (theContent starts "<QuickBets") then
    
    QI(#patron).QuickBets(theContent)
    
  else if (theContent starts "<Wager") then
    
    QI(#patron).Wager(theContent)
    
  end if
end


