-------------------------------------------------------------------------------
-- Name: class InternetBrowser
-- Author: Jonathan Primeau
--
-- Description:
--     This class takes care of the internet browsers. It makes the abstraction
--     between WebXtra and Mozilla Xtra. You can then call GoBack and this 
--     class will dispatch it to the current browser.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent
property pScrollStep
property pBrowserSprite
property pMozFieldTypes
property pCurrentURL
property pLastURL
property pBackState


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = void
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on NavigateActionURL (me)
  lAction = QI(#nav).GetAction()
  
  if (voidP(lAction.getaProp(#toolbar)) = false) then
    lToolbar = lAction.toolbar
    QI(#web).SetToolbar(lToolbar)
  else
    -- Default: toolbar on
    QI(#web).SetToolbar(true)
  end if
  
  if (voidP(lAction.getaProp(#userAgent)) = false) then
    lUserAgent = lAction.userAgent
    me.SetUserAgent(lUserAgent)
  end if
  
  if (lAction.getaProp(#url) <> void) then
    lURL = lAction.url
    me.OpenPage(lURL)
  end if
end

on OpenPage (me, theURL)
  lBrowser = QI(#status).GetCurrentBrowser()
  
  me.pCurrentURL = theURL
  
  GenLog(#debug, "WebBrowser::OpenPage:"&& lBrowser && theURL)
  
  if (lBrowser = "WebXtra") then
    
    sprite(me.pBrowserSprite).silent = true
    sprite(me.pBrowserSprite).Navigate(theURL)
    
  else if (lBrowser = "WebViewerXtra") then
    
    sprite(me.pBrowserSprite).contextMenu = false
    sprite(me.pBrowserSprite).scrollBars = false
    sprite(me.pBrowserSprite).selectable = false
    sprite(me.pBrowserSprite).silent = true
    sprite(me.pBrowserSprite).Navigate(theURL)
    
  else if (lBrowser starts "MozillaXtra") then
    
    sprite(me.pBrowserSprite).scrollbars = false
    sprite(me.pBrowserSprite).Moz_OpenLocation(theURL)
    
  end if
  
  GenLog(#debug, "WebBrowser::OpenPage:"&& lBrowser && "loaded!")
end

on SetUserAgent (me, theUserAgent)
  
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser starts "MozillaXtra") then 
    sprite(me.pBrowserSprite).Moz_SetUserAgent(theUserAgent)
  end if
end

on SetToolbar (me, theState)
  
  if (theState = false) then
    -- Hide toolbar
    sprite("webBack").locH = -500
    sprite("webBack,text").locH = -500
    
    sprite("webForward").locH = -500
    sprite("webForward,text").locH = -500
    
    sprite("webScrollUp").locH = -500
    sprite("webScrollUp,text").locH = -500
    
    sprite("webScrollDown").locH = -500
    sprite("webScrollDown,text").locH = -500
    
    sprite("webScrollLeft").locH = -500
    sprite("webScrollLeft,text").locH = -500
    
    sprite("webScrollRight").locH = -500
    sprite("webScrollRight,text").locH = -500
    
    -- Make the browser bigger
    if (SpriteExists("webBrowser")) then
      sprite("webBrowser").top = 134
    end if
  end if
end

on StopLoading (me)
  GenLog(#debug, "WebBrowser::StopLoading: Stop loading page...")
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser = "WebXtra") then
    
    sprite(me.pBrowserSprite).Stop()
    
  else if (lBrowser = "WebViewerXtra") then
    
    sprite(me.pBrowserSprite).Stop()
    
  else if (lBrowser starts "MozillaXtra") then 
    
    sprite(me.pBrowserSprite).Moz_Stop("?")
    
  end if
end

on SetBackState (me, theState)
  me.pBackState = theState
end

on GoBack (me)
  GenLog(#debug, "WebBrowser::GoBack: Going back...")
  
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser = "WebXtra") then
    
    if (me.pBackState = true) then
      sprite(me.pBrowserSprite).GoBack()
    else
      QI(#nav).GoBack()
    end if
    
  else if (lBrowser = "WebViewerXtra") then
    
    if (me.pBackState = true) then
      sprite(me.pBrowserSprite).GoBack()
    else
      QI(#nav).GoBack()
    end if
    
  else if (lBrowser starts "MozillaXtra") then 
    
    lBackAvailable = sprite(me.pBrowserSprite).Moz_GoBack()
    if (lBackAvailable = false) then
      QI(#nav).GoBack()
    end if
  end if
end

on GoForward (me)
  GenLog(#debug, "WebBrowser::GoForward: Going forward...")
  
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser = "WebXtra") then
    
    sprite(me.pBrowserSprite).GoForward()
    
  else if (lBrowser = "WebViewerXtra") then
    
    sprite(me.pBrowserSprite).GoForward()
    
  else if (lBrowser starts "MozillaXtra") then 
    
    sprite(me.pBrowserSprite).Moz_GoForward()
    
  end if
end

on ScrollUp (me)
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser = "WebXtra") then
    
    sprite(me.pBrowserSprite).ScrollWindow(0, me.pScrollStep * -1)
    
  else if (lBrowser = "WebViewerXtra") then
    
    sprite(me.pBrowserSprite).ScrollBy(0, me.pScrollStep * -1)
    
  else if (lBrowser starts "MozillaXtra") then 
    
    lCurrPos = sprite(me.pBrowserSprite).Moz_GetScrollPos(1)
    sprite(me.pBrowserSprite).Moz_SetScrollPos(1, lCurrPos - me.pScrollStep)
    
  end if
end

on ScrollDown (me)
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser = "WebXtra") then
    
    sprite(me.pBrowserSprite).ScrollWindow(0, me.pScrollStep)
    
  else if (lBrowser = "WebViewerXtra") then
    
    sprite(me.pBrowserSprite).ScrollBy(0, me.pScrollStep)
    
  else if (lBrowser starts "MozillaXtra") then 
    
    lCurrPos = sprite(me.pBrowserSprite).Moz_GetScrollPos(1)
    sprite(me.pBrowserSprite).Moz_SetScrollPos(1, lCurrPos + me.pScrollStep)
    
  end if
end

on ScrollLeft (me)
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser = "WebXtra") then
    
    sprite(me.pBrowserSprite).ScrollWindow(me.pScrollStep * -1, 0)
    
  else if (lBrowser = "WebViewerXtra") then
    
    sprite(me.pBrowserSprite).ScrollBy(me.pScrollStep * -1, 0)
    
  else if (lBrowser starts "MozillaXtra") then 
    
    lCurrPos = sprite(me.pBrowserSprite).Moz_GetScrollPos(2)
    sprite(me.pBrowserSprite).Moz_SetScrollPos(2, lCurrPos - me.pScrollStep)
    
  end if
end

on ScrollRight (me)
  lBrowser = QI(#status).GetCurrentBrowser()
  
  if (lBrowser = "WebXtra") then
    
    sprite(me.pBrowserSprite).ScrollWindow(me.pScrollStep, 0)
    
  else if (lBrowser = "WebViewerXtra") then
    
    sprite(me.pBrowserSprite).ScrollBy(me.pScrollStep, 0)
    
  else if (lBrowser starts "MozillaXtra") then 
    
    lCurrPos = sprite(me.pBrowserSprite).Moz_GetScrollPos(2)
    sprite(me.pBrowserSprite).Moz_SetScrollPos(2, lCurrPos + me.pScrollStep)
    
  end if
end

-------------------------------------------------------------------------------
-- M O Z I L L A  M E T H O D S
-------------------------------------------------------------------------------

on MozillaSetEditField (me, theName, theValue, theFrame)
  GenLog(#debug, "WebBrowser::SetEditField: Setting field" && string(theName) && string(theValue))
  sprite(me.pBrowserSprite).Moz_EditFieldSelected(theName, theValue, theFrame)
end

on MozillaFieldFocus (me, theParams)
  lName = string(theParams.name)
  lValue = string(theParams.value)
  lType = string(theParams.type)
  lFrame = string(theParams.frame)
  
  if (lName = "") then
    GenLog(#error, "WebBrowser::MozillaFieldFocus: Field name empty on" && me.pURL)
  end if
  
  if (lType = "") then
    GenLog(#error, "WebBrowser::MozillaFieldFocus: Field type empty on" && me.pURL)
  end if
  
  if (me.pMozFieldTypes.getPos(lType) <> 0) then
    QI(#vkb).Show(lName, lValue, lType, lFrame)
  else
    GenLog(#debug, "WebBrowser::MozillaFieldFocus: Field type not supported" && lType)
  end if
end

on CheckURLMozillaXtra (me, theURL, theFrameName)
  lURL = string(theURL)
  lFrameName = string(theFrameName)
  
  me.pLastURL = lURL
  
  if (lFrameName <> "") then
    -- Frame request, just allow it
    return(true)
  end if
  
  -- Try URL and return true if not deny or ignore
  lStatus = false
  if (lURL <> "") then
    lAddToHistory = true
    if (lURL starts "ogn://" = false) then
      lAddToHistory = false
    end if
    lStatus = QI(#nav).Navigate(lURL, lAddToHistory, true)
  end if
  
  -- WebLoad commented out for now until we find a solution BUG: 186
  --  if (lStatus = true and lURL starts "ogn://" = false) then
  --    QI(#webLoad).Show()
  --  end if
  return(lStatus)
end

on CheckURLWebXtra (me, theURL, theFrameName)
  lURL = string(theURL)
  lFrameName = string(theFrameName)
  
  -- Protects us from endless loop
  if (lURL = me.pLastURL) then
    -- Already verified, just allow it
    return(true)
  end if
  
  me.pLastURL = lURL
  
  if (lFrameName <> "") then
    -- Frame request, just allow it
    return(true)
  end if
  
  -- Try URL and return true if not deny or ignore
  lStatus = false
  if (lURL <> "") then
    lStatus = QI(#nav).Navigate(lURL, false, true)
  end if
  
  -- WebLoad commented out for now until we find a solution BUG: 186
  --  if (lStatus = true and lURL starts "ogn://" = false) then
  --    QI(#webLoad).Show()
  --  end if
  return(lStatus)
end

on CheckURLWebViewerXtra (me, theURL, theFrameName)
  lURL = string(theURL)
  lFrameName = string(theFrameName)
  
  -- Protects us from endless loop
  if (lURL = me.pLastURL) then
    -- Already verified, just allow it
    return(true)
  end if
  
  me.pLastURL = lURL
  
  if (lFrameName <> "") then
    -- Frame request, just allow it
    return(true)
  end if
  
  -- Try URL and return true if not deny or ignore
  lStatus = false
  if (lURL <> "") then
    lStatus = QI(#nav).Navigate(lURL, false, true)
  end if
  
  -- WebLoad commented out for now until we find a solution BUG: 186
  --  if (lStatus = true and lURL starts "ogn://" = false) then
  --    QI(#webLoad).Show()
  --  end if
  return(lStatus)
end

on DocumentComplete (me)
  me.pLastURL = ""
  -- WebLoad commented out for now until we find a solution BUG: 186
  --QI(#webLoad).Hide()
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pScrollStep = QI(#config).GetScrollingStep()
  me.pBrowserSprite = "WebBrowser"
  me.pCurrentURL = ""
  
  me.pMozFieldTypes = []
  me.pMozFieldTypes.add("field")
  me.pMozFieldTypes.add("text")
  me.pMozFieldTypes.add("password")
  me.pMozFieldTypes.add("textarea")
  
  me.pLastURL = ""
  
  me.pBackState = false
end
